@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2020 Accurics, Inc.
+    Copyright (C) 2022 Tenable, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -22,7 +22,6 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/accurics/terrascan/pkg/utils"
 	"github.com/hashicorp/go-version"
 	"github.com/hashicorp/hcl"
 	svchost "github.com/hashicorp/terraform-svchost"
@@ -33,6 +32,7 @@ import (
 	"github.com/hashicorp/terraform/registry"
 	"github.com/hashicorp/terraform/registry/regsrc"
 	"github.com/hashicorp/terraform/registry/response"
+	"github.com/tenable/terrascan/pkg/utils"
 	"go.uber.org/zap"
 )
 
@@ -48,6 +48,21 @@ func newRemoteModuleInstaller() *remoteModuleInstaller {
 
 // newTerraformRegistryClient returns a client to query terraform registries
 func newTerraformRegistryClient() terraformRegistryClient {
+
+	// as terraform supports passing terraformrc file location through TF_CLI_CONFIG_FILE env
+	// we can make use of the same
+	// check for TF_CLI_CONFIG_FILE env if found use
+	// else check for default location which is home dir
+	configFile := os.Getenv("TF_CLI_CONFIG_FILE")
+	if configFile != "" {
+		if _, err := os.Stat(configFile); os.IsNotExist(err) {
+			return registry.NewClient(nil, nil)
+		}
+		zap.S().Debugf("Found terraform rc file at %s, attempting to parse", configFile)
+
+		return NewAuthenticatedRegistryClient(configFile)
+	}
+
 	// get terraform registry client.
 	// terraform registry client provides methods for querying the terraform module registry
 	// if terraformrc file is found, attempt to load credentials from it
