@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2021 Accurics, Inc.
+    Copyright (C) 2022 Tenable, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -17,8 +17,8 @@
 package config
 
 import (
-	fn "github.com/accurics/terrascan/pkg/mapper/iac-providers/cft/functions"
 	"github.com/awslabs/goformation/v5/cloudformation/cloudformation"
+	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // CloudFormationStackConfig holds config for aws_cloudformation_stack
