@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2020 Accurics, Inc.
+    Copyright (C) 2022 Tenable, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -23,27 +23,27 @@ import (
 	"reflect"
 	"testing"
 
-	tfv15 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v15"
-	"github.com/accurics/terrascan/pkg/results"
-	"github.com/accurics/terrascan/pkg/vulnerability"
 	"github.com/hashicorp/go-multierror"
+	tfv15 "github.com/tenable/terrascan/pkg/iac-providers/terraform/v15"
+	"github.com/tenable/terrascan/pkg/results"
+	"github.com/tenable/terrascan/pkg/vulnerability"
 
-	iacProvider "github.com/accurics/terrascan/pkg/iac-providers"
-	armv1 "github.com/accurics/terrascan/pkg/iac-providers/arm/v1"
-	cftv1 "github.com/accurics/terrascan/pkg/iac-providers/cft/v1"
-	dockerv1 "github.com/accurics/terrascan/pkg/iac-providers/docker/v1"
-	helmv3 "github.com/accurics/terrascan/pkg/iac-providers/helm/v3"
-	k8sv1 "github.com/accurics/terrascan/pkg/iac-providers/kubernetes/v1"
-	kustomizev4 "github.com/accurics/terrascan/pkg/iac-providers/kustomize/v4"
-	tfv12 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v12"
-	tfv14 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v14"
-	"github.com/accurics/terrascan/pkg/notifications/webhook"
+	iacProvider "github.com/tenable/terrascan/pkg/iac-providers"
+	armv1 "github.com/tenable/terrascan/pkg/iac-providers/arm/v1"
+	cftv1 "github.com/tenable/terrascan/pkg/iac-providers/cft/v1"
+	dockerv1 "github.com/tenable/terrascan/pkg/iac-providers/docker/v1"
+	helmv3 "github.com/tenable/terrascan/pkg/iac-providers/helm/v3"
+	k8sv1 "github.com/tenable/terrascan/pkg/iac-providers/kubernetes/v1"
+	kustomizev4 "github.com/tenable/terrascan/pkg/iac-providers/kustomize/v4"
+	tfv12 "github.com/tenable/terrascan/pkg/iac-providers/terraform/v12"
+	tfv14 "github.com/tenable/terrascan/pkg/iac-providers/terraform/v14"
+	"github.com/tenable/terrascan/pkg/notifications/webhook"
 
-	"github.com/accurics/terrascan/pkg/config"
-	"github.com/accurics/terrascan/pkg/iac-providers/output"
-	"github.com/accurics/terrascan/pkg/notifications"
-	"github.com/accurics/terrascan/pkg/policy"
-	"github.com/accurics/terrascan/pkg/utils"
+	"github.com/tenable/terrascan/pkg/config"
+	"github.com/tenable/terrascan/pkg/iac-providers/output"
+	"github.com/tenable/terrascan/pkg/notifications"
+	"github.com/tenable/terrascan/pkg/policy"
+	"github.com/tenable/terrascan/pkg/utils"
 )
 
 var (
