@@ -5,8 +5,7 @@ set -o nounset
 set -o pipefail
 
 GIT_COMMIT=$(git rev-parse --short HEAD 2>/dev/null)
-DOCKER_REPO="accurics/terrascan"
-DOCKERFILE="./build/Dockerfile"
+DOCKER_REPO="tenable/terrascan"
 LATEST_TAG=$(git describe --abbrev=0 --tags)
 LATEST_TAG_SHORT=$(echo "${LATEST_TAG//v}")
 
